gradoptics.distributions.gaussian\_distribution
=============================================

.. automodule:: gradoptics.distributions.gaussian_distribution
   :members:
   :undoc-members:
   :show-inheritance:
